==> 2205.0.tar.gz: o3de/Gems/Blast/Code/blast_files.cmake <==
#
# Copyright (c) Contributors to the Open 3D Engine Project.
# For complete copyright and license terms please see the LICENSE at the root of this distribution.
#
# SPDX-License-Identifier: Apache-2.0 OR MIT
#
#

set(FILES
    Include/Blast/BlastActor.h
    Include/Blast/BlastActorData.h
    Include/Blast/BlastFamilyComponentBus.h
    Include/Blast/BlastMaterial.h
    Include/Blast/BlastSystemBus.h
    Include/Blast/BlastDebug.h
    Source/Actor/BlastActorDesc.h
    Source/Actor/BlastActorFactory.h
    Source/Actor/BlastActorFactory.cpp
    Source/Actor/BlastActorImpl.h
    Source/Actor/BlastActorImpl.cpp
    Source/Actor/EntityProvider.h
    Source/Actor/EntityProvider.cpp
    Source/Actor/ShapesProvider.h
    Source/Actor/ShapesProvider.cpp
    Source/Asset/BlastAsset.h
    Source/Asset/BlastAsset.cpp
    Source/Asset/BlastAssetHandler.h
    Source/Asset/BlastAssetHandler.cpp
    Source/Asset/BlastChunksAsset.h
    Source/Asset/BlastChunksAsset.cpp
    Source/Components/BlastFamilyComponent.h
    Source/Components/BlastFamilyComponent.cpp
    Source/Components/BlastFamilyComponentNotificationBusHandler.h
    Source/Components/BlastFamilyComponentNotificationBusHandler.cpp
    Source/Components/BlastMeshDataComponent.h
    Source/Components/BlastMeshDataComponent.cpp
    Source/Components/BlastSystemComponent.cpp
    Source/Components/BlastSystemComponent.h
    Source/Family/ActorRenderManager.h
    Source/Family/ActorRenderManager.cpp
    Source/Family/ActorTracker.h
    Source/Family/ActorTracker.cpp
    Source/Family/BlastFamily.h
    Source/Family/BlastFamilyImpl.h
    Source/Family/BlastFamilyImpl.cpp
    Source/Family/DamageManager.h
    Source/Family/DamageManager.cpp
    Source/Common/BlastInterfaces.h
    Source/Common/BlastMaterial.cpp
    Source/Common/Utils.h
)

==> 2210.0.tar.gz: o3de/Gems/Blast/Code/blast_files.cmake <==
#
# Copyright (c) Contributors to the Open 3D Engine Project.
# For complete copyright and license terms please see the LICENSE at the root of this distribution.
#
# SPDX-License-Identifier: Apache-2.0 OR MIT
#
#

set(FILES
    Include/Blast/BlastActor.h
    Include/Blast/BlastActorConfiguration.h
    Include/Blast/BlastActorData.h
    Include/Blast/BlastFamilyComponentBus.h
    Include/Blast/BlastSystemBus.h
    Include/Blast/BlastDebug.h
    Source/Actor/BlastActorDesc.h
    Source/Actor/BlastActorFactory.h
    Source/Actor/BlastActorFactory.cpp
    Source/Actor/BlastActorImpl.h
    Source/Actor/BlastActorImpl.cpp
    Source/Actor/EntityProvider.h
    Source/Actor/EntityProvider.cpp
    Source/Actor/ShapesProvider.h
    Source/Actor/ShapesProvider.cpp
    Source/Asset/BlastAsset.h
    Source/Asset/BlastAsset.cpp
    Source/Asset/BlastAssetHandler.h
    Source/Asset/BlastAssetHandler.cpp
    Source/Asset/BlastChunksAsset.h
    Source/Asset/BlastChunksAsset.cpp
    Source/Components/BlastFamilyComponent.h
    Source/Components/BlastFamilyComponent.cpp
    Source/Components/BlastFamilyComponentNotificationBusHandler.h
    Source/Components/BlastFamilyComponentNotificationBusHandler.cpp
    Source/Components/BlastMeshDataComponent.h
    Source/Components/BlastMeshDataComponent.cpp
    Source/Components/BlastSystemComponent.cpp
    Source/Components/BlastSystemComponent.h
    Source/Family/ActorRenderManager.h
    Source/Family/ActorRenderManager.cpp
    Source/Family/ActorTracker.h
    Source/Family/ActorTracker.cpp
    Source/Family/BlastFamily.h
    Source/Family/BlastFamilyImpl.h
    Source/Family/BlastFamilyImpl.cpp
    Source/Family/DamageManager.h
    Source/Family/DamageManager.cpp
    Source/Common/BlastInterfaces.h
    Source/Common/Utils.h
    Source/Material/BlastMaterial.h
    Source/Material/BlastMaterial.cpp
    Source/Material/BlastMaterialAsset.h
    Source/Material/BlastMaterialAsset.cpp
    Source/Material/BlastMaterialConfiguration.h
    Source/Material/BlastMaterialConfiguration.cpp
)
